@@ -11,6 +11,7 @@ class MxRecord(BaseModel):
 
 class Plugins(BaseModel):
     blocklist: Optional[bool] = None
+    gravatarUrl: Optional[str] = None
     compromiseDetector: Optional[bool] = None
     mxRecords: Optional[List[MxRecord]] = None
     nsfw: Optional[bool] = None
@@ -21,7 +22,9 @@ class Plugins(BaseModel):
     urlShortener: Optional[bool] = None
 
 class VerifyPlugins(Enum):
+    BLOCKLIST = "blocklist"
     COMPROMISE_DETECTOR = "compromiseDetector"
+    GRAVATAR_URL = "gravatarUrl"
     MX_RECORDS = "mxRecords"
     NSFW = "nsfw"
     REPUTATION = "reputation"
@@ -29,7 +32,6 @@ class VerifyPlugins(Enum):
     TOR_NETWORK = "torNetwork"
     TYPOSQUATTING = "typosquatting"
     URL_SHORTENER = "urlShortener"
-    BLOCKLIST = "blocklist"
 
 class PhoneData(BaseModel):
     iso: Optional[str] = None
@@ -50,6 +52,7 @@ class Validator(BaseModel):
     ip: Optional[str] = None
     wallet: Optional[str] = None
     userAgent: Optional[str] = None
+    iban: Optional[str] = None
     plugins: Optional[List[VerifyPlugins]] = None
 
 class UrlEncryptResponse(BaseModel):
@@ -258,6 +261,19 @@ class DataVerifierUserAgent(BaseModel):
     device: DataVerifierDevice
     plugins: Optional[Dict[str, Any]] = None
 
+class DataVerifierIBAN(BaseModel):
+    valid: bool
+    fraud: Optional[bool] = None
+    iban: Optional[str] = None
+    bban: Optional[str] = None
+    bic: Optional[str] = "unknown"
+    country: Optional[str] = None
+    countryCode: Optional[str] = None
+    accountNumber: Optional[str] = None
+    branchIdentifier: Optional[str] = None
+    bankIdentifier: Optional[str] = None
+    plugins: Optional[Dict[str, Any]] = None
+
 class DataVerifierResponse(BaseModel):
     url: Optional[DataVerifierURL]
     email: Optional[DataVerifierEmail]
@@ -266,6 +282,7 @@ class DataVerifierResponse(BaseModel):
     creditCard: Optional[DataVerifierCreditCard]
     ip: Optional[DataVerifierIp]
     userAgent: Optional[DataVerifierUserAgent]
+    iban: Optional[DataVerifierIBAN]
 
 class SRNG(BaseModel):
     min: int
